package com.trafficparrot.sdk.jms;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.collect.ComparisonChain;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;

public class Destination implements Comparable<Destination> {
    public final String name;
    public final DestinationType type;

    public Destination(@JsonProperty("name") String name,
                       @JsonProperty("type") DestinationType type) {
        this.name = name;
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        return EqualsBuilder.reflectionEquals(this, o);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    @Override
    @JsonIgnore
    public String toString() {
        return type + ":" + name;
    }

    @Override
    public int compareTo(Destination other) {
        return ComparisonChain.start()
                .compare(name, other.name)
                .compare(type, other.type)
                .result();
    }
}
