package com.trafficparrot.sdk.example.jms;

import com.trafficparrot.sdk.jms.Destination;
import com.trafficparrot.sdk.jms.JmsResponse;
import com.trafficparrot.sdk.jms.TpLogger;
import org.junit.Test;

import javax.jms.TextMessage;

import static com.trafficparrot.sdk.jms.DestinationType.QUEUE;
import static org.junit.Assert.assertEquals;
import static org.mockito.Mockito.*;

public class GenerateJsonResponseBasedOnRequestTest {
    private static final Destination REQUEST_DESTINATION = new Destination("order_queue", QUEUE);
    private static final Destination RESPONSE_DESTINATION = new Destination("response_queue", QUEUE);
    private static final JmsResponse RESPONSE = new JmsResponse(RESPONSE_DESTINATION,  "response text");
    private final GenerateJsonResponseBasedOnRequest generateResponseBasedOnRequest = new GenerateJsonResponseBasedOnRequest();
    private final TextMessage requestMessage = mock(TextMessage.class);

    @Test
    public void createsAResponseWithOddNumberOfItemsAndOrderAcceptedFalse() throws Exception {
        when(requestMessage.getText()).thenReturn("{\n" +
                "   \"orderId\": 9999888800001,\n" +
                "   \"storeId\": 34009450,\n" +
                "   \"orderItems\": [{" +
                "     \"orderItemId\": 999988880000101,\n" +
                "     \"partnumber\": \"0012311077738\",\n" +
                "     \"quantity\": 1\n" +
                "   }]}\n" +
                " ");

        JmsResponse response = generateResponseBasedOnRequest.transform(REQUEST_DESTINATION, requestMessage, RESPONSE);

        assertEquals(
                "{\n" +
                        "  \"orderAccepted\" : false,\n" +
                        "  \"orderItems\" : [ {\n" +
                        "    \"orderItemId\" : 999988880000101,\n" +
                        "    \"quantity\" : 1,\n" +
                        "    \"sku\" : \"0012311077738\"\n" +
                        "  } ]\n" +
                        "}", response.text);
    }

    @Test
    public void createsAResponseWithEvenNumberOfItemsAndOrderAcceptedTrue() throws Exception {
        when(requestMessage.getText()).thenReturn("{\n" +
                "   \"orderId\": 9999888800001,\n" +
                "   \"storeId\": 34009450,\n" +
                "   \"orderItems\": [{" +
                "     \"orderItemId\": 999988880000101,\n" +
                "     \"partnumber\": \"0012311077738\",\n" +
                "     \"quantity\": 1\n" +
                "   }, {" +
                "     \"orderItemId\": 999988880000102,\n" +
                "     \"partnumber\": \"0012311077739\",\n" +
                "     \"quantity\": 10\n" +
                "   }]}\n" +
                " ");

        JmsResponse response = generateResponseBasedOnRequest.transform(REQUEST_DESTINATION, requestMessage, RESPONSE);

        assertEquals(
                "{\n" +
                        "  \"orderAccepted\" : true,\n" +
                        "  \"orderItems\" : [ {\n" +
                        "    \"orderItemId\" : 999988880000101,\n" +
                        "    \"quantity\" : 1,\n" +
                        "    \"sku\" : \"0012311077738\"\n" +
                        "  }, {\n" +
                        "    \"orderItemId\" : 999988880000102,\n" +
                        "    \"quantity\" : 10,\n" +
                        "    \"sku\" : \"0012311077739\"\n" +
                        "  } ]\n" +
                        "}", response.text);
    }

}